.. -*- coding: utf-8 -*-

.. _`vesicle-library-dataset`:

Large System Vesicle Benchmark Library
======================================

Large benchmark systems for MDAnalysis (and other codes)

Coarse-grained (DryMartini force field) vesicle systems were generated
with the scripts in the `vesicle_library
<https://github.com/Becksteinlab/vesicle_library>`_ by Ian Kenney. All
files are in GRO format and contain a static system. For further
details about the data set see [Kenney2015]_.

The files are placed into the Public Domain (made available under the
CC0 license).

========= ============
system     # particles
========= ============
  1_75M      1748952
  3_5M       3497904
 10M        10074000
========= ============

Notes
-----

Data set characteristics:

 :size: 807 MB
 :number of structures: 3
 :number of frames:  1
 :number of particles: varies
 :creator: Ian Kenney
 :URL:  `10.6084/m9.figshare.3406708.v1 <https://doi.org/10.6084/m9.figshare.3406708.v1>`_
 :license: `CC0 <https://creativecommons.org/publicdomain/zero/1.0/legalcode>`_
 :reference: [Kenney2015]_
    

.. [Kenney2015] M. Kenney, I. and Beckstein, O. (2015) *Technical
		Report: SPIDAL Summer REU 2015: Biomolecular benchmark
		systems*. figshare. doi:
		`10.6084/m9.figshare.1588804.v1
		<https://doi.org/10.6084/m9.figshare.1588804.v1>`_.
